@@ -1,4 +1,3 @@
-skip_on_cran() # Uses chromote
 require("shiny", quietly = TRUE, character.only = TRUE)
 
 test_that("Saving an app has the right context", {
@@ -15,13 +14,11 @@ test_that("Saving an app has the right context", {
   )
 
   app <- AppDriver$new(shiny_app)
+
   expect_equal(
     app$get_value(output = "text"),
     as.character(n)
   )
-
-  # Shut down this app to try an make CI happier about the next app
-  app$stop()
 })
 
 
@@ -37,6 +34,7 @@ test_that("can run saved app", {
   path <- app_save(shinyApp(ui, server))
 
   app <- AppDriver$new(path)
+
   expect_equal(app$get_value(output = "x"), as.character(x))
 })
 
